params: Common Parameters in 'power'

paramsR Documentation

Common Parameters in power

Description

The parameters below are commonly used throughout the power package.

Arguments

nsim

integer(1). Number of simulations to perform in estimating power, (1 - \beta).

alpha

double(1). The significance threshold (\alpha), the probability of a significant result given the null hypothesis, i.e. a false positive. If desired, Bonferroni correction should be implemented here.

n

integer(1). The sample size.

n_vec

integer(n). A sequence of sample sizes per group to evaluate the corresponding power.

delta

double(1). The effect size.

delta_vec

numeric(n). A sequence of effect sizes to evaluate the corresponding power.

power_vec

numeric(n) in ⁠(0, 1)⁠. A sequence of power levels to evaluate the required samples size.

main

character(1). Optional title.


stufield/power documentation built on June 1, 2025, 7:16 p.m.