| fisher_power | R Documentation |
Calculates the empirical power of a test through simulated data for a given effect size of sample size (per group).
fisher_power(p1, p2, n1, n2, nsim = 200L, alpha = 0.05, ...)
p1 |
The first proportion (group 1). |
p2 |
The second proportion (group 2). |
n1 |
The group 1 sample size (column 1). |
n2 |
The group 2 sample size (column 2). |
nsim |
|
alpha |
|
... |
Passed to the underlying test, i.e. |
fisher_power(0.8, 0.7, 100, 100)
fisher_power(0.6, 0.7, 50, 60)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.