View source: R/fisher-power-curve.R
| fisher_power_curve | R Documentation |
Generates data for a power curve where power is empirically estimated over a range of sample size values.
S3 print method for fisher_power_curve objects.
S3 plot method for fisher_power_curve objects.
fisher_power_curve(n_vec, p = 0.85, p_diff = -0.1, nsim = 200L, ...)
## S3 method for class 'fisher_power_curve'
print(x, ...)
## S3 method for class 'fisher_power_curve'
plot(x, ...)
n_vec |
|
p |
|
p_diff |
|
nsim |
|
... |
Arguments passed to |
x |
A |
t_power_curve()
tbl <- fisher_power_curve(seq(50, 400, 10), nsim = 100L)
tbl
plot(tbl)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.