| t_test_power | R Documentation |
Calculates the empirical power of a test through simulated data for a given effect size of sample size (per group).
t_test_power(n, delta, nsim = 200L, alpha = 0.05, ...)
n |
|
delta |
|
nsim |
|
alpha |
|
... |
Passed to the underlying test, i.e. |
The value of the empirically calculated power (1 - \beta).
Stu Field
t.test(), qt(), rnorm()
t_test_power(10, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.